"""
This is a boilerplate pipeline 'sajid_test_file'
generated using Kedro 0.18.3
"""

from kedro.pipeline import Pipeline, node, pipeline


def create_pipeline(**kwargs) -> Pipeline:
    return pipeline([])
