# -*- coding: utf-8 -*-
from setuptools import setup, find_packages

setup(
    name="sajid_test_file",
    version="0.1",
    description="Micro-package `sajid_test_file`",
    packages=find_packages(),
    include_package_data=True,
    install_requires=[],
)
